@@ -2,6 +2,7 @@
 import json
 import os
 from datetime import date, timedelta
+from decimal import Decimal
 
 from pagador.configuracao.cadastro import CampoFormulario, FormularioBase, TipoDeCampo, CadastroBase, SelecaoBase, FormatoDeCampo, ValidadorBase, caminho_para_template
 from pagador.configuracao.cliente import Script, TipoScript
@@ -88,7 +89,7 @@ class ValidarJson(ValidadorBase):
             return u''.join([x for x in s if x.isdigit()])
 
         banco = data.get('banco')
-        bancos_limites = {"2": 5, "1": 7, "6": 6, "4": 6, "7": 7, "3": 7}
+        bancos_limites = {"2": 5, "1": 7, "6": 6, "4": 6, "7": 8, "3": 5}
         for i in ['empresa_cnpj', 'banco_agencia', 'banco_conta', 'banco_convenio']:
             if data.get(i):
                 valor = so_numeros(data[i])
@@ -100,7 +101,7 @@ class ValidarJson(ValidadorBase):
                     tamanho_atual = len(data[i])
                     if banco == "4" and not tamanho_atual in [6, 7, 8]:
                         self.erros[i] = u"Certifique-se de que o valor tenha 6, 7 ou 8 caracteres (ele possui {}).".format(tamanho_atual)
-                    if banco == "7" and not tamanho_atual == 7:
+                    if banco in ["3", "7"] and not tamanho_atual == 7:
                         self.erros[i] = u"Certifique-se de que o valor tenha 7 caracteres (ele possui {}).".format(tamanho_atual)
 
         if data.get('desconto_valor', None):
@@ -126,8 +127,9 @@ class ValidarJson(ValidadorBase):
 
 class Formulario(FormularioBase):
     json = CampoFormulario("json", "", requerido=True, ordem=1, tipo=TipoDeCampo.oculto, formato=FormatoDeCampo.json, validador=ValidarJson)
-    desconto_valor = CampoFormulario("desconto_valor", u"Desconto aplicado", requerido=False, ordem=2, tipo=TipoDeCampo.decimal)
-    aplicar_no_total = CampoFormulario("aplicar_no_total", u"Aplicar no total?", requerido=False, ordem=3, tipo=TipoDeCampo.boleano, texto_ajuda=u"Aplicar desconto no total da compra (incluir por exemplo o frete).")
+    valor_minimo_aceitado = CampoFormulario("valor_minimo_aceitado", u"Valor mínimo", requerido=False, decimais=2, ordem=2, tipo=TipoDeCampo.decimal, texto_ajuda=u"Informe o valor mínimo para exibir essa forma de pagamento")
+    desconto_valor = CampoFormulario("desconto_valor", u"Desconto aplicado", requerido=False, ordem=3, tipo=TipoDeCampo.decimal)
+    aplicar_no_total = CampoFormulario("aplicar_no_total", u"Aplicar no total?", requerido=False, ordem=4, tipo=TipoDeCampo.boleano, texto_ajuda=u"Aplicar desconto no total da compra (incluir por exemplo o frete).")
 
 
 class MeioPagamentoEnvio(object):
@@ -155,6 +157,13 @@ class MeioPagamentoSelecao(SelecaoBase):
     selecao = Script(tipo=TipoScript.html, nome="selecao", caminho_arquivo=caminho_do_arquivo_de_template("selecao.html"), eh_template=True)
 
     def to_dict(self):
+        try:
+            valor_pagamento = Decimal(self.dados.get("valor_pagamento", None))
+        except (ValueError, TypeError):
+            valor_pagamento = None
+        if self.configuracao.valor_minimo_aceitado and valor_pagamento:
+            if valor_pagamento < self.configuracao.valor_minimo_aceitado:
+                return []
         return [
-            self.selecao.to_dict()
+            self.selecao.to_dict(),
         ]
